@@ -39,6 +39,7 @@ def get_pretrained_network(file_id=None,
             "brainExtraction": "https://ndownloader.figshare.com/files/22944632",
             "brainExtractionT1": "https://ndownloader.figshare.com/files/27334370",
             "brainExtractionT1v1": "https://ndownloader.figshare.com/files/28057626",
+            "brainExtractionRobustT1": "https://figshare.com/ndownloader/files/34792930",
             "brainExtractionT2": "https://ndownloader.figshare.com/files/23066153",
             "brainExtractionFLAIR": "https://ndownloader.figshare.com/files/23562194",
             "brainExtractionBOLD": "https://ndownloader.figshare.com/files/22761977",
@@ -138,6 +139,7 @@ def get_pretrained_network(file_id=None,
                   "brainExtraction",
                   "brainExtractionT1",
                   "brainExtractionT1v1",
+                  "brainExtractionRobustT1",
                   "brainExtractionT2",
                   "brainExtractionFLAIR",
                   "brainExtractionBOLD",
